aboutsummaryrefslogtreecommitdiff
path: root/src/output_internal.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/output_internal.h')
-rw-r--r--src/output_internal.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/output_internal.h b/src/output_internal.h
index e53fc6a6..d2b6e41b 100644
--- a/src/output_internal.h
+++ b/src/output_internal.h
@@ -63,23 +63,23 @@ struct audio_output {
* The audio_format in which audio data is received from the
* player thread (which in turn receives it from the decoder).
*/
- struct audio_format inAudioFormat;
+ struct audio_format in_audio_format;
/**
* The audio_format which is really sent to the device. This
* is basically reqAudioFormat (if configured) or
* inAudioFormat, but may have been modified by
* plugin->open().
*/
- struct audio_format outAudioFormat;
+ struct audio_format out_audio_format;
/**
* The audio_format which was configured. Only set if
* convertAudioFormat is true.
*/
- struct audio_format reqAudioFormat;
+ struct audio_format config_audio_format;
- struct pcm_convert_state convState;
+ struct pcm_convert_state convert_state;
/**
* The thread handle, or NULL if the output thread isn't
@@ -63,23 +63,23 @@ struct audio_output {
/**
* The audio_format which is really sent to the device. This
- * is basically reqAudioFormat (if configured) or
- * inAudioFormat, but may have been modified by
+ * is basically config_audio_format (if configured) or
+ * in_audio_format, but may have been modified by
* plugin->open().
*/